@@ -60,6 +60,7 @@ const char *piModelNames [16] =
 	"ODROID-N1",
 	"ODROID-N2/N2Plus",
 	"ODROID-C4",
+	"ODROID-HC4",
 };
 
 const char *piRevisionNames [16] =
@@ -501,6 +502,11 @@ int piGpioLayout (void) {
 			libwiring.mem = 4;
 			libwiring.rev = 1;
 			break;
+		case MODEL_ODROID_HC4:
+			libwiring.maker = MAKER_AMLOGIC;
+			libwiring.mem = 4;
+			libwiring.rev = 1;
+			break;
 		case MODEL_UNKNOWN:
 		default:
 			libwiring.model = MAKER_UNKNOWN;
@@ -1208,6 +1214,9 @@ int wiringPiSetup (void)
 	case MODEL_ODROID_C4:
 		init_odroidc4(&libwiring);
 	break;
+	case MODEL_ODROID_HC4:
+		init_odroidhc4(&libwiring);
+	break;
 	default:
 		return wiringPiFailure (WPI_ALMOST,
 			"wiringPiSetup: Unknown model\n");
